Validator

Trait Validator 

pub trait Validator:
    Send
    + Sync
    + 'static {
    // Required methods
    fn validate(&self, value: &str) -> Option<String>;
    fn name(&self) -> &'static str;
}
A validation rule that can be applied to a string value.

Required Methods

fn validate(&self, value: &str) -> Option<String>

Returns None if valid, or an error message string if invalid.

fn name(&self) -> &'static str

Human-readable name for this rule (used in error messages).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors