pub struct Positioned { /* private fields */ }Expand description
Absolutely places a child inside a Stack using
edge anchors. Receives the full stack rect and positions its child from
the given top/left/right/bottom (+ optional explicit width/height).
A child with no anchors fills the stack (the default Stack behavior).
Implementations
Sourceimpl Positioned
impl Positioned