Structs
- Rect
Reader - Fires
atom.set(Some(ctx.rect))after paint, surfacing the widget’s window-pixel coordinates to user code without any widget modification.
atom.set(Some(ctx.rect)) after paint, surfacing the widget’s
window-pixel coordinates to user code without any widget modification.