pub struct WidgetBox(pub Box<dyn Widget>);Expand description
Concrete wrapper that stores a Box<dyn Widget> inside a NativeElement.
The element walker in the umbrella crate downcasts NativeElement.payload
to this type to retrieve the widget for layout + paint.
Tuple Fields
0: Box<dyn Widget>Trait Implementations